## Overview

Python library for thenewboston.

## Project Setup

Install required packages:
```
pip3 install -r requirements.txt
```

## Testing

To run tests:
```
pytest
```

## Building

To produce a source distribution:
```
python3 setup.py sdist
```
